============
Installation
============

You should have `Numpy` and `SciPy` installed prior to installation.

If you have virtualenvwrapper installed::

    $ mkvirtualenv regressors
    $ pip install numpy scipy
    $ pip install regressors

Or, at the command line::

    $ easy_install numpy scipy
    $ easy_install regressors
